@@ -18,7 +18,7 @@ import (
 
 const (
 	HelmRequiredVersion           = "v3.10.3"
-	HelmRecommendedVersion        = "v3.11.2"
+	HelmRecommendedVersion        = "v3.11.3"
 	HelmDiffRecommendedVersion    = "v3.4.0"
 	HelmSecretsRecommendedVersion = "v4.1.1"
 	HelmGitRecommendedVersion     = "v0.12.0"
@@ -163,7 +163,7 @@ func (h *HelmfileInit) WhetherContinue(ask string) error {
 
 func (h *HelmfileInit) CheckHelmPlugins() error {
 	settings := cli.New()
-	helm := helmexec.New(h.helmBinary, false, h.logger, "", h.runner)
+	helm := helmexec.New(h.helmBinary, helmexec.HelmExecOptions{}, h.logger, "", h.runner)
 	for _, p := range helmPlugins {
 		pluginVersion, err := helmexec.GetPluginVersion(p.name, settings.PluginsDirectory)
 		if err != nil {
