@@ -6,8 +6,6 @@ type DiffOptions struct {
 	Set []string
 	// Values is the values flag
 	Values []string
-	// SkipDeps is the skip deps flag
-	SkipDeps bool
 	// DetailedExitcode is the detailed exit code
 	DetailedExitcode bool
 	// IncludeTests is the include tests flag
@@ -83,11 +81,6 @@ func (t *DiffImpl) Set() []string {
 	return t.DiffOptions.Set
 }
 
-// SkipDeps returns the skip deps
-func (t *DiffImpl) SkipDeps() bool {
-	return t.DiffOptions.SkipDeps
-}
-
 // SkipNeeds returns the skip needs
 func (t *DiffImpl) SkipNeeds() bool {
 	if !t.IncludeNeeds() {
